==> blesta-5.10.2.zip: blesta/core/Automation/Tasks/Task/language/fr_fr/cleanup_logs.php <==
<?php
/**
 * Cleanup Logs
 *
 * @package blesta
 * @subpackage blesta.language.fr_fr
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Automation.task.cleanup_logs.attempt'] = 'Tentative de nettoyage des anciens journaux.';
$lang['Automation.task.cleanup_logs.completed'] = 'La tâche de nettoyage des journaux est terminée.';
$lang['Automation.task.cleanup_logs.logs_gateway_deleted'] = 'Les anciens journaux de la passerelle %1$s ont été supprimés.';
$lang['Automation.task.cleanup_logs.logs_module_deleted'] = 'Les anciens journaux du module %1$s ont été supprimés.';
$lang['Automation.task.cleanup_logs.logs_accountaccess_deleted'] = 'Les anciens journaux d\'accès au compte %1$s ont été supprimés.';
$lang['Automation.task.cleanup_logs.logs_contact_deleted'] = 'Les anciens journaux de contact %1$s ont été supprimés.';
$lang['Automation.task.cleanup_logs.logs_email_deleted'] = 'Les anciens journaux d\'e-mails de %1$s ont été supprimés.';
$lang['Automation.task.cleanup_logs.logs_messenger_deleted'] = 'Les anciens journaux Messenger de %1$s ont été supprimés.';
$lang['Automation.task.cleanup_logs.logs_user_deleted'] = 'Les anciens journaux de l\'utilisateur %1$s ont été supprimés.';
$lang['Automation.task.cleanup_logs.logs_client_settings_deleted'] = 'Les anciens journaux de paramétrage du client %1$s ont été supprimés.';
$lang['Automation.task.cleanup_logs.logs_service_deleted'] = 'Les anciens journaux de service %1$s ont été supprimés.';
$lang['Automation.task.cleanup_logs.logs_transaction_deleted'] = 'Les anciens journaux de transactions (%1$s) ont été supprimés.';
$lang['Automation.task.cleanup_logs.logs_cron_deleted'] = 'Les anciens journaux Cron de %1$s ont été supprimés.';

==> blesta-5.11.4.zip: blesta/core/Automation/Tasks/Task/language/fr_fr/cleanup_logs.php <==
<?php
/**
 * Cleanup Logs
 *
 * @package blesta
 * @subpackage blesta.language.fr_fr
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Automation.task.cleanup_logs.attempt'] = 'Tentative de nettoyage des anciens journaux.';
$lang['Automation.task.cleanup_logs.completed'] = 'La tâche de nettoyage des journaux est terminée.';
$lang['Automation.task.cleanup_logs.logs_gateway_deleted'] = 'Les anciens journaux de la passerelle %1$s ont été supprimés.';
$lang['Automation.task.cleanup_logs.logs_module_deleted'] = 'Les anciens journaux du module %1$s ont été supprimés.';
$lang['Automation.task.cleanup_logs.logs_accountaccess_deleted'] = 'Les anciens journaux d\'accès au compte %1$s ont été supprimés.';
$lang['Automation.task.cleanup_logs.logs_contact_deleted'] = 'Les anciens journaux de contact %1$s ont été supprimés.';
$lang['Automation.task.cleanup_logs.logs_email_deleted'] = 'Les anciens journaux d\'e-mails de %1$s ont été supprimés.';
$lang['Automation.task.cleanup_logs.logs_messenger_deleted'] = 'Les anciens journaux Messenger de %1$s ont été supprimés.';
$lang['Automation.task.cleanup_logs.logs_user_deleted'] = 'Les anciens journaux de l\'utilisateur %1$s ont été supprimés.';
$lang['Automation.task.cleanup_logs.logs_client_settings_deleted'] = 'Les anciens journaux de paramétrage du client %1$s ont été supprimés.';
$lang['Automation.task.cleanup_logs.logs_service_deleted'] = 'Les anciens journaux de service %1$s ont été supprimés.';
$lang['Automation.task.cleanup_logs.logs_transaction_deleted'] = 'Les anciens journaux de transactions (%1$s) ont été supprimés.';
$lang['Automation.task.cleanup_logs.logs_cron_deleted'] = 'Les anciens journaux Cron de %1$s ont été supprimés.';
$lang['Automation.task.cleanup_logs.logs_service_changes_deleted'] = '%1$s les anciens journaux de modifications de service ont été supprimés.';
